@@ -2,12 +2,14 @@ package Router::Simple;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 use Router::Simple::SubMapper;
 use Router::Simple::Route;
 use List::Util qw/max/;
 use Carp ();
 
+our $_METHOD_NOT_ALLOWED;
+
 sub new {
     bless {routes => []}, shift;
 }
@@ -44,13 +46,21 @@ sub _match {
         $env = +{ PATH_INFO => $env }
     }
 
+    local $_METHOD_NOT_ALLOWED;
+    $self->{method_not_allowed} = 0;
     for my $route (@{$self->{routes}}) {
         my $match = $route->match($env);
         return ($match, $route) if $match;
     }
+    $self->{method_not_allowed} = $_METHOD_NOT_ALLOWED;
     return undef; # not matched.
 }
 
+sub method_not_allowed {
+    my $self = shift;
+    $self->{method_not_allowed};
+}
+
 sub match {
     my ($self, $req) = @_;
     my ($match) = $self->_match($req);
@@ -169,6 +179,10 @@ are stored in the special key C<splat>.
 
 Creates a new instance of Router::Simple.
 
+=item $router->method_not_allowed() : Boolean
+
+This method returns last C<< $router->match() >> call is rejected by HTTP method or not.
+
 =item $router->connect([$name, ] $pattern, \%destination[, \%options])
 
 Adds a new rule to $router.
